@@ -12,7 +12,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXdup.c,v 1.3 2005/04/26 20:01:33 hobbs Exp $
+ * $Id: tclXdup.c,v 1.2 2002/09/26 00:19:18 hobbs Exp $
  *-----------------------------------------------------------------------------
  */
 #include "tclExtdInt.h"
@@ -21,20 +21,20 @@
  * Prototypes of internal functions.
  */
 static int
-DupChannelOptions _ANSI_ARGS_((Tcl_Interp  *interp,
-                               Tcl_Channel  srcChannel,
-                               Tcl_Channel  targetChannel));
+DupChannelOptions (Tcl_Interp  *interp,
+                   Tcl_Channel  srcChannel,
+                   Tcl_Channel  targetChannel);
 
 static Tcl_Channel
-DupFileChannel _ANSI_ARGS_((Tcl_Interp *interp,
-                            char       *srcFileId,
-                            char       *targetFileId));
+DupFileChannel (Tcl_Interp *interp,
+                char       *srcFileId,
+                char       *targetFileId);
 
 static int
-TclX_DupObjCmd _ANSI_ARGS_((ClientData   clientData,
-                            Tcl_Interp  *interp,
-                            int          objc,
-                            Tcl_Obj     *CONST objv[]));
+TclX_DupObjCmd (ClientData   clientData,
+                Tcl_Interp  *interp,
+                int          objc,
+                Tcl_Obj     *CONST objv[]);
 
 
 /*-----------------------------------------------------------------------------
@@ -51,13 +51,12 @@ TclX_DupObjCmd _ANSI_ARGS_((ClientData   clientData,
  *-----------------------------------------------------------------------------
  */
 static int
-DupChannelOptions (interp, srcChannel, targetChannel)
-    Tcl_Interp  *interp;
-    Tcl_Channel  srcChannel;
-    Tcl_Channel  targetChannel;
+DupChannelOptions (Tcl_Interp *interp,
+                   Tcl_Channel srcChannel,
+                   Tcl_Channel targetChannel)
 {
     Tcl_DString strValues;
-    CONST84 char *option, *value, **optArgv = NULL;
+    const char *option, *value, **optArgv = NULL;
     int optArgc, idx;
 
     Tcl_DStringInit (&strValues);
@@ -76,7 +75,7 @@ DupChannelOptions (interp, srcChannel, targetChannel)
         goto errorExit;
     }
     if ((optArgc % 2) != 0) {
-        panic("channel didn't return keyword/value pairs");
+        Tcl_Panic("channel didn't return keyword/value pairs");
     }
 
     for (idx = 0; idx < optArgc; idx += 2) {
@@ -122,13 +121,10 @@ DupChannelOptions (interp, srcChannel, targetChannel)
  *-----------------------------------------------------------------------------
  */
 static Tcl_Channel
-DupFileChannel (interp, srcChannelId, targetChannelId)
-    Tcl_Interp *interp;
-    char       *srcChannelId;
-    char       *targetChannelId;
+DupFileChannel (Tcl_Interp *interp, char *srcChannelId, char *targetChannelId)
 {
     Tcl_Channel srcChannel, newChannel = NULL;
-    Tcl_ChannelType *channelType;
+    const Tcl_ChannelType *channelType;
     int mode;
 
     srcChannel = Tcl_GetChannel (interp, srcChannelId, &mode);
@@ -194,11 +190,10 @@ DupFileChannel (interp, srcChannelId, targetChannelId)
  *-----------------------------------------------------------------------------
  */
 static int
-TclX_DupObjCmd (clientData, interp, objc, objv)
-    ClientData   clientData;
-    Tcl_Interp  *interp;
-    int          objc;
-    Tcl_Obj     *CONST objv[];
+TclX_DupObjCmd (ClientData clientData,
+                Tcl_Interp *interp,
+                int objc,
+                Tcl_Obj *CONST objv[])
 {
     Tcl_Channel newChannel;
     int bindFnum, fnum;
@@ -274,8 +269,7 @@ TclX_DupObjCmd (clientData, interp, objc, objv)
  *-----------------------------------------------------------------------------
  */
 void
-TclX_DupInit (interp)
-    Tcl_Interp *interp;
+TclX_DupInit (Tcl_Interp *interp)
 {
     Tcl_CreateObjCommand (interp, 
 			  "dup",
@@ -285,3 +279,5 @@ TclX_DupInit (interp)
 }
 
 
+
+/* vim: set ts=4 sw=4 sts=4 et : */
