@@ -12,7 +12,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXfcntl.c,v 1.2 2005/01/19 03:20:47 hobbs Exp $
+ * $Id: tclXfcntl.c,v 1.1 2001/10/24 23:31:48 hobbs Exp $
  *-----------------------------------------------------------------------------
  */
 
@@ -65,27 +65,27 @@ static struct {
  * Prototypes of internal functions.
  */
 static int
-XlateFcntlAttr  _ANSI_ARGS_((Tcl_Interp  *interp,
-                             char        *attrName,
-                             int          modify));
+XlateFcntlAttr  (Tcl_Interp  *interp,
+                 char        *attrName,
+                 int          modify);
 
 static int
-GetFcntlAttr _ANSI_ARGS_((Tcl_Interp  *interp,
-                          Tcl_Channel  channel,
-                          int          mode,
-                          int          attrib));
+GetFcntlAttr (Tcl_Interp  *interp,
+              Tcl_Channel  channel,
+              int          mode,
+              int          attrib);
 
 static int
-SetFcntlAttrObj _ANSI_ARGS_((Tcl_Interp  *interp,
-                             Tcl_Channel  channel,
-                             int          attrib,
-                             Tcl_Obj     *valueObj));
+SetFcntlAttrObj (Tcl_Interp  *interp,
+                 Tcl_Channel  channel,
+                 int          attrib,
+                 Tcl_Obj     *valueObj);
 
 static int 
-TclX_FcntlObjCmd _ANSI_ARGS_((ClientData clientData, 
-                              Tcl_Interp *interp,
-                              int objc,
-                              Tcl_Obj *CONST objv[]));
+TclX_FcntlObjCmd (ClientData clientData, 
+                  Tcl_Interp *interp,
+                  int objc,
+                  Tcl_Obj *CONST objv[]);
 
 
 /*-----------------------------------------------------------------------------
@@ -102,10 +102,7 @@ TclX_FcntlObjCmd _ANSI_ARGS_((ClientData clientData,
  *-----------------------------------------------------------------------------
  */
 static int
-XlateFcntlAttr (interp, attrName, modify)
-    Tcl_Interp  *interp;
-    char        *attrName;
-    int          modify;
+XlateFcntlAttr (Tcl_Interp *interp, char *attrName, int modify)
 {
     char attrNameUp [MAX_ATTR_NAME_LEN];
     int idx;
@@ -156,11 +153,7 @@ XlateFcntlAttr (interp, attrName, modify)
  *-----------------------------------------------------------------------------
  */
 static int
-GetFcntlAttr (interp, channel, mode, attrib)
-    Tcl_Interp  *interp;
-    Tcl_Channel  channel;
-    int          mode;
-    int          attrib;
+GetFcntlAttr (Tcl_Interp *interp, Tcl_Channel channel, int mode, int attrib)
 {
     int value, optValue;
 
@@ -207,11 +200,16 @@ GetFcntlAttr (interp, channel, mode, attrib)
         value = (optValue == TCLX_BUFFERING_LINE);
         break;
       case ATTR_KEEPALIVE:
-        if (TclXOSgetsockopt (interp, channel, SO_KEEPALIVE, &value) != TCL_OK)
+        {
+        socklen_t len;
+        if (TclXOSgetsockopt (interp, channel, SO_KEEPALIVE, &len) != TCL_OK)
             return TCL_ERROR;
+        value = len;
+        }
         break;
       default:
-        panic ("bug in fcntl get attrib");
+        Tcl_Panic ("bug in fcntl get attrib");
+        value = 0; /* suppress compiler warning for initialized value */
     }
 
     Tcl_SetIntObj (Tcl_GetObjResult (interp), value != 0);
@@ -232,11 +230,10 @@ GetFcntlAttr (interp, channel, mode, attrib)
  *-----------------------------------------------------------------------------
  */
 static int
-SetFcntlAttrObj (interp, channel, attrib, valueObj)
-    Tcl_Interp  *interp;
-    Tcl_Channel  channel;
-    int          attrib;
-    Tcl_Obj     *valueObj;
+SetFcntlAttrObj (Tcl_Interp *interp,
+                 Tcl_Channel channel,
+                 int attrib,
+                 Tcl_Obj *valueObj)
 {
     int value;
 
@@ -267,7 +264,7 @@ SetFcntlAttrObj (interp, channel, attrib, valueObj)
       case ATTR_KEEPALIVE:
         return TclXOSsetsockopt (interp, channel, SO_KEEPALIVE, value);
       default:
-        panic ("buf in fcntl set attrib");
+        Tcl_Panic ("buf in fcntl set attrib");
     }
     return TCL_ERROR;  /* Should never be reached */
 }
@@ -279,11 +276,10 @@ SetFcntlAttrObj (interp, channel, attrib, valueObj)
  *-----------------------------------------------------------------------------
  */
 static int
-TclX_FcntlObjCmd (clientData, interp, objc, objv)
-    ClientData  clientData;
-    Tcl_Interp *interp;
-    int         objc;
-    Tcl_Obj    *CONST objv[];
+TclX_FcntlObjCmd (ClientData clientData,
+                  Tcl_Interp *interp,
+                  int objc,
+                  Tcl_Obj *CONST objv[])
 {
     Tcl_Channel  channel;
     int          mode;
@@ -324,8 +320,7 @@ TclX_FcntlObjCmd (clientData, interp, objc, objv)
  *-----------------------------------------------------------------------------
  */
 void
-TclX_FcntlInit (interp)
-    Tcl_Interp *interp;
+TclX_FcntlInit (Tcl_Interp *interp)
 {
     Tcl_CreateObjCommand (interp, 
 			  "fcntl",
@@ -334,3 +329,5 @@ TclX_FcntlInit (interp)
 			  (Tcl_CmdDeleteProc*) NULL);
 }
 
+
+/* vim: set ts=4 sw=4 sts=4 et : */
