@@ -12,11 +12,12 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXkeylist.c,v 1.5 2005/03/24 05:06:39 hobbs Exp $
+ * $Id: tclXkeylist.c,v 1.7 2005/11/21 18:39:11 hobbs Exp $
  *-----------------------------------------------------------------------------
  */
 
 #include "tclExtdInt.h"
+#include <stdint.h>
 
 /*
  * Keyed lists are stored as arrays recursively defined objects.  The data
@@ -70,6 +71,9 @@ typedef struct {
 /*
  * Macro to duplicate a child entry of a keyed list if it is share by more
  * than the parent.
+ * NO_KEYLIST_HASH_TABLE: We don't duplicate the hash table, so ensure
+ * that consistency checks allow for portions where not all entries are
+ * in the hash table.
  */
 #define DupSharedKeyListChild(keylIntPtr, idx) \
     if (Tcl_IsShared(keylIntPtr->entries [idx].valuePtr)) { \
@@ -98,68 +102,68 @@ typedef struct {
  */
 #ifdef TCLX_DEBUG
 static void
-ValidateKeyedList _ANSI_ARGS_((keylIntObj_t *keylIntPtr));
+ValidateKeyedList (keylIntObj_t *keylIntPtr);
 #endif
 static int
-ValidateKey _ANSI_ARGS_((Tcl_Interp *interp, char *key, int keyLen));
+ValidateKey (Tcl_Interp *interp, char *key, int keyLen);
 
 static keylIntObj_t *
-AllocKeyedListIntRep _ANSI_ARGS_((void));
+AllocKeyedListIntRep (void);
 
 static void
-FreeKeyedListData _ANSI_ARGS_((keylIntObj_t *keylIntPtr));
+FreeKeyedListData (keylIntObj_t *keylIntPtr);
 
 static void
-EnsureKeyedListSpace _ANSI_ARGS_((keylIntObj_t *keylIntPtr,
-				  int		newNumEntries));
+EnsureKeyedListSpace (keylIntObj_t *keylIntPtr,
+                      int		newNumEntries);
 
 static void
-DeleteKeyedListEntry _ANSI_ARGS_((keylIntObj_t *keylIntPtr,
-				  int		entryIdx));
+DeleteKeyedListEntry (keylIntObj_t *keylIntPtr,
+                      int		entryIdx);
 
 static int
-FindKeyedListEntry _ANSI_ARGS_((keylIntObj_t *keylIntPtr,
-				char	     *key,
-				int	     *keyLenPtr,
-				char	    **nextSubKeyPtr));
+FindKeyedListEntry (keylIntObj_t *keylIntPtr,
+                    char	     *key,
+                    int	     *keyLenPtr,
+                    char	    **nextSubKeyPtr);
 
 static void
-DupKeyedListInternalRep _ANSI_ARGS_((Tcl_Obj *srcPtr,
-				     Tcl_Obj *copyPtr));
+DupKeyedListInternalRep (Tcl_Obj *srcPtr,
+                         Tcl_Obj *copyPtr);
 
 static void
-FreeKeyedListInternalRep _ANSI_ARGS_((Tcl_Obj *keylPtr));
+FreeKeyedListInternalRep (Tcl_Obj *keylPtr);
 
 static int
-SetKeyedListFromAny _ANSI_ARGS_((Tcl_Interp *interp,
-				 Tcl_Obj    *objPtr));
+SetKeyedListFromAny (Tcl_Interp *interp,
+                     Tcl_Obj    *objPtr);
 
 static void
-UpdateStringOfKeyedList _ANSI_ARGS_((Tcl_Obj *keylPtr));
+UpdateStringOfKeyedList (Tcl_Obj *keylPtr);
 
 static int 
-TclX_KeylgetObjCmd _ANSI_ARGS_((ClientData   clientData,
-				Tcl_Interp  *interp,
-				int	     objc,
-				Tcl_Obj	    *CONST objv[]));
+TclX_KeylgetObjCmd (ClientData   clientData,
+                    Tcl_Interp  *interp,
+                    int	     objc,
+                    Tcl_Obj	    *CONST objv[]);
 
 static int
-TclX_KeylsetObjCmd _ANSI_ARGS_((ClientData   clientData,
-				Tcl_Interp  *interp,
-				int	     objc,
-				Tcl_Obj	    *CONST objv[]));
+TclX_KeylsetObjCmd (ClientData   clientData,
+                    Tcl_Interp  *interp,
+                    int	     objc,
+                    Tcl_Obj	    *CONST objv[]);
 
 static int 
-TclX_KeyldelObjCmd _ANSI_ARGS_((ClientData   clientData,
-				Tcl_Interp  *interp,
-				int	     objc,
-				Tcl_Obj	    *CONST objv[]));
+TclX_KeyldelObjCmd (ClientData   clientData,
+                    Tcl_Interp  *interp,
+                    int	     objc,
+                    Tcl_Obj	    *CONST objv[]);
 
 static int 
-TclX_KeylkeysObjCmd _ANSI_ARGS_((ClientData   clientData,
-				 Tcl_Interp  *interp,
-				 int	      objc,
-				 Tcl_Obj     *CONST objv[]));
+TclX_KeylkeysObjCmd (ClientData   clientData,
+                     Tcl_Interp  *interp,
+                     int	      objc,
+                     Tcl_Obj     *CONST objv[]);
 
 /*
  * Type definition.
@@ -182,8 +186,7 @@ static Tcl_ObjType keyedListType = {
  */
 #ifdef TCLX_DEBUG
 static void
-ValidateKeyedList (keylIntPtr)
-    keylIntObj_t *keylIntPtr;
+ValidateKeyedList (KeylIntObj_t *keylIntPtr)
 {
     int idx;
 
@@ -219,10 +222,7 @@ ValidateKeyedList (keylIntPtr)
  *-----------------------------------------------------------------------------
  */
 static int
-ValidateKey (interp, key, keyLen)
-    Tcl_Interp *interp;
-    char *key;
-    int keyLen;
+ValidateKey (Tcl_Interp *interp, char *key, int keyLen)
 {
     if (strlen (key) != (size_t) keyLen) {
 	Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
@@ -254,10 +254,8 @@ AllocKeyedListIntRep ()
     keylIntPtr = (keylIntObj_t *) ckalloc (sizeof (keylIntObj_t));
     memset(keylIntPtr, 0, sizeof (keylIntObj_t));
 #ifndef NO_KEYLIST_HASH_TABLE
-#if 1
     keylIntPtr->hashTbl = (Tcl_HashTable *) ckalloc(sizeof(Tcl_HashTable));
     Tcl_InitHashTable(keylIntPtr->hashTbl, TCL_STRING_KEYS);
-#endif
 #endif
     return keylIntPtr;
 }
@@ -271,8 +269,7 @@ AllocKeyedListIntRep ()
  *-----------------------------------------------------------------------------
  */
 static void
-FreeKeyedListData (keylIntPtr)
-    keylIntObj_t *keylIntPtr;
+FreeKeyedListData (keylIntObj_t *keylIntPtr)
 {
     int idx;
 
@@ -303,9 +300,7 @@ FreeKeyedListData (keylIntPtr)
  *-----------------------------------------------------------------------------
  */
 static void
-EnsureKeyedListSpace (keylIntPtr, newNumEntries)
-    keylIntObj_t *keylIntPtr;
-    int		  newNumEntries;
+EnsureKeyedListSpace (keylIntObj_t *keylIntPtr, int newNumEntries)
 {
     KEYL_REP_ASSERT (keylIntPtr);
 
@@ -336,9 +331,7 @@ EnsureKeyedListSpace (keylIntPtr, newNumEntries)
  *-----------------------------------------------------------------------------
  */
 static void
-DeleteKeyedListEntry (keylIntPtr, entryIdx)
-    keylIntObj_t *keylIntPtr;
-    int		  entryIdx;
+DeleteKeyedListEntry (keylIntObj_t *keylIntPtr, int entryIdx)
 {
     int idx;
 
@@ -346,24 +339,25 @@ DeleteKeyedListEntry (keylIntPtr, entryIdx)
     if (keylIntPtr->hashTbl != NULL) {
 	Tcl_HashEntry *entryPtr;
 	Tcl_HashSearch search;
-	int nidx;
+	intptr_t nidx;
 
 	entryPtr = Tcl_FindHashEntry(keylIntPtr->hashTbl,
 		keylIntPtr->entries [entryIdx].key);
 	if (entryPtr != NULL) {
-	    idx = (int) Tcl_GetHashValue(entryPtr);
 	    Tcl_DeleteHashEntry(entryPtr);
+	}
 
-	    /*
-	     * In order to maintain consistency, we have to iterate over
-	     * the entire hash table to find and decr relevant idxs.
-	     */
-	    for (entryPtr = Tcl_FirstHashEntry(keylIntPtr->hashTbl, &search);
-		 entryPtr != NULL; entryPtr = Tcl_NextHashEntry(&search)) {
-		nidx = (int) Tcl_GetHashValue(entryPtr);
-		if (nidx > idx) {
-		    Tcl_SetHashValue(entryPtr, nidx - 1);
-		}
+	/*
+	 * In order to maintain consistency, we have to iterate over
+	 * the entire hash table to find and decr relevant idxs.
+	 * We have to do this even if the previous index was not found
+	 * in the hash table, as Dup'ing doesn't dup the hash tables.
+	 */
+	for (entryPtr = Tcl_FirstHashEntry(keylIntPtr->hashTbl, &search);
+	     entryPtr != NULL; entryPtr = Tcl_NextHashEntry(&search)) {
+	    nidx = (intptr_t) Tcl_GetHashValue(entryPtr);
+	    if (nidx > entryIdx) {
+		Tcl_SetHashValue(entryPtr, (ClientData) (uintptr_t) (nidx - 1));
 	    }
 	}
     }
@@ -395,14 +389,14 @@ DeleteKeyedListEntry (keylIntPtr, entryIdx)
  *-----------------------------------------------------------------------------
  */
 static int
-FindKeyedListEntry (keylIntPtr, key, keyLenPtr, nextSubKeyPtr)
-    keylIntObj_t *keylIntPtr;
-    char	 *key;
-    int		 *keyLenPtr;
-    char	**nextSubKeyPtr;
+FindKeyedListEntry (keylIntObj_t *keylIntPtr,
+                    char	     *key,
+                    int	     *keyLenPtr,
+                    char	    **nextSubKeyPtr)
 {
     char *keySeparPtr;
-    int keyLen, findIdx = -1;
+    int keyLen;
+    intptr_t findIdx = -1;
 
     keySeparPtr = strchr (key, '.');
     if (keySeparPtr != NULL) {
@@ -424,7 +418,7 @@ FindKeyedListEntry (keylIntPtr, key, keyLenPtr, nextSubKeyPtr)
 	}
 	entryPtr = Tcl_FindHashEntry(keylIntPtr->hashTbl, key);
 	if (entryPtr != NULL) {
-	    findIdx = (int) Tcl_GetHashValue(entryPtr);
+	    findIdx = (intptr_t) Tcl_GetHashValue(entryPtr);
 	}
 	if (keySeparPtr != NULL) {
 	    key[keyLen] = tmp;
@@ -468,8 +462,7 @@ FindKeyedListEntry (keylIntPtr, key, keyLenPtr, nextSubKeyPtr)
  *-----------------------------------------------------------------------------
  */
 static void
-FreeKeyedListInternalRep (keylPtr)
-    Tcl_Obj *keylPtr;
+FreeKeyedListInternalRep (Tcl_Obj *keylPtr)
 {
     FreeKeyedListData ((keylIntObj_t *) keylPtr->internalRep.otherValuePtr);
 }
@@ -484,9 +477,7 @@ FreeKeyedListInternalRep (keylPtr)
  *-----------------------------------------------------------------------------
  */
 static void
-DupKeyedListInternalRep (srcPtr, copyPtr)
-    Tcl_Obj *srcPtr;
-    Tcl_Obj *copyPtr;
+DupKeyedListInternalRep (Tcl_Obj *srcPtr, Tcl_Obj *copyPtr)
 {
     keylIntObj_t *srcIntPtr =
 	(keylIntObj_t *) srcPtr->internalRep.otherValuePtr;
@@ -505,6 +496,11 @@ DupKeyedListInternalRep (srcPtr, copyPtr)
     copyIntPtr->hashTbl = (Tcl_HashTable *) ckalloc(sizeof(Tcl_HashTable));
     Tcl_InitHashTable(copyIntPtr->hashTbl, TCL_STRING_KEYS);
 #else
+    /*
+     * NO_KEYLIST_HASH_TABLE: We don't duplicate the hash table, so ensure
+     * that consistency checks allow for portions where not all entries are
+     * in the hash table.
+     */
     copyIntPtr->hashTbl = NULL;
 #endif
 #endif
@@ -541,9 +537,7 @@ DupKeyedListInternalRep (srcPtr, copyPtr)
  *-----------------------------------------------------------------------------
  */
 static int
-SetKeyedListFromAny (interp, objPtr) 
-    Tcl_Interp *interp;
-    Tcl_Obj    *objPtr;
+SetKeyedListFromAny (Tcl_Interp *interp, Tcl_Obj *objPtr) 
 {
     keylIntObj_t *keylIntPtr;
     keylEntry_t *keyEntryPtr;
@@ -601,7 +595,7 @@ SetKeyedListFromAny (interp, objPtr)
 #ifndef NO_KEYLIST_HASH_TABLE
 	entryPtr = Tcl_CreateHashEntry(keylIntPtr->hashTbl,
 		keyEntryPtr->key, &dummy);
-	Tcl_SetHashValue(entryPtr, idx);
+	Tcl_SetHashValue(entryPtr, (ClientData) (uintptr_t) idx);
 #endif
 
 	keylIntPtr->numEntries++;
@@ -627,8 +621,7 @@ SetKeyedListFromAny (interp, objPtr)
  *-----------------------------------------------------------------------------
  */
 static void
-UpdateStringOfKeyedList (keylPtr)
-    Tcl_Obj  *keylPtr;
+UpdateStringOfKeyedList (Tcl_Obj *keylPtr)
 {
 #define UPDATE_STATIC_SIZE 32
     int idx, strLen;
@@ -709,43 +702,43 @@ TclX_NewKeyedListObj ()
  *-----------------------------------------------------------------------------
  */
 int
-TclX_KeyedListGet (interp, keylPtr, key, valuePtrPtr)
-    Tcl_Interp *interp;
-    Tcl_Obj    *keylPtr;
-    char       *key;
-    Tcl_Obj   **valuePtrPtr;
+TclX_KeyedListGet (Tcl_Interp *interp,
+                   Tcl_Obj    *keylPtr,
+                   char       *key,
+                   Tcl_Obj   **valuePtrPtr)
 {
     keylIntObj_t *keylIntPtr;
     char *nextSubKey;
     int findIdx;
 
     while (1) {
-	if (Tcl_ConvertToType (interp, keylPtr, &keyedListType) != TCL_OK)
-	    return TCL_ERROR;
-	keylIntPtr = (keylIntObj_t *) keylPtr->internalRep.otherValuePtr;
-	KEYL_REP_ASSERT (keylIntPtr);
+        if (Tcl_ConvertToType (interp, keylPtr, &keyedListType) != TCL_OK)
+            return TCL_ERROR;
 
-	findIdx = FindKeyedListEntry(keylIntPtr, key, NULL, &nextSubKey);
+        keylIntPtr = (keylIntObj_t *) keylPtr->internalRep.otherValuePtr;
+        KEYL_REP_ASSERT (keylIntPtr);
 
-	/*
-	 * If not found, return status.
-	 */
-	if (findIdx < 0) {
-	    *valuePtrPtr = NULL;
-	    return TCL_BREAK;
-	}
+        findIdx = FindKeyedListEntry(keylIntPtr, key, NULL, &nextSubKey);
 
-	/*
-	 * If we are at the last subkey, return the entry, otherwise recurse
-	 * down looking for the entry.
-	 */
-	if (nextSubKey == NULL) {
-	    *valuePtrPtr = keylIntPtr->entries [findIdx].valuePtr;
-	    return TCL_OK;
-	} else {
-	    keylPtr = keylIntPtr->entries [findIdx].valuePtr;
-	    key = nextSubKey;
-	}
+        /*
+         * If not found, return status.
+         */
+        if (findIdx < 0) {
+            *valuePtrPtr = NULL;
+            return TCL_BREAK;
+        }
+
+        /*
+         * If we are at the last subkey, return the entry, otherwise recurse
+         * down looking for the entry.
+         */
+        if (nextSubKey == NULL) {
+            *valuePtrPtr = keylIntPtr->entries [findIdx].valuePtr;
+            return TCL_OK;
+        } else {
+            keylPtr = keylIntPtr->entries [findIdx].valuePtr;
+            key = nextSubKey;
+        }
     }
 }
 
@@ -764,11 +757,10 @@ TclX_KeyedListGet (interp, keylPtr, key, valuePtrPtr)
  *-----------------------------------------------------------------------------
  */
 int
-TclX_KeyedListSet (interp, keylPtr, key, valuePtr)
-    Tcl_Interp *interp;
-    Tcl_Obj    *keylPtr;
-    char       *key;
-    Tcl_Obj    *valuePtr;
+TclX_KeyedListSet (Tcl_Interp *interp,
+                   Tcl_Obj    *keylPtr,
+                   char       *key,
+                   Tcl_Obj    *valuePtr)
 {
     keylIntObj_t *keylIntPtr;
     keylEntry_t *keyEntryPtr;
@@ -814,7 +806,7 @@ TclX_KeyedListSet (interp, keylPtr, key, valuePtr)
 	    }
 	    entryPtr = Tcl_CreateHashEntry(keylIntPtr->hashTbl,
 		    keyEntryPtr->key, &dummy);
-	    Tcl_SetHashValue(entryPtr, findIdx);
+	    Tcl_SetHashValue(entryPtr, (ClientData) (uintptr_t) findIdx);
 #endif
 	    Tcl_InvalidateStringRep (keylPtr);
 
@@ -864,7 +856,7 @@ TclX_KeyedListSet (interp, keylPtr, key, valuePtr)
 	    }
 	    entryPtr = Tcl_CreateHashEntry(keylIntPtr->hashTbl,
 		    keyEntryPtr->key, &dummy);
-	    Tcl_SetHashValue(entryPtr, findIdx);
+	    Tcl_SetHashValue(entryPtr, (ClientData) (uintptr_t) findIdx);
 #endif
 	    Tcl_InvalidateStringRep (keylPtr);
 	}
@@ -890,10 +882,7 @@ TclX_KeyedListSet (interp, keylPtr, key, valuePtr)
  *-----------------------------------------------------------------------------
  */
 int
-TclX_KeyedListDelete (interp, keylPtr, key)
-    Tcl_Interp *interp;
-    Tcl_Obj    *keylPtr;
-    char       *key;
+TclX_KeyedListDelete (Tcl_Interp *interp, Tcl_Obj *keylPtr, char *key)
 {
     keylIntObj_t *keylIntPtr, *subKeylIntPtr;
     char *nextSubKey;
@@ -964,11 +953,10 @@ TclX_KeyedListDelete (interp, keylPtr, key)
  *-----------------------------------------------------------------------------
  */
 int
-TclX_KeyedListGetKeys (interp, keylPtr, key, listObjPtrPtr)
-    Tcl_Interp *interp;
-    Tcl_Obj    *keylPtr;
-    char       *key;
-    Tcl_Obj   **listObjPtrPtr;
+TclX_KeyedListGetKeys (Tcl_Interp *interp,
+                       Tcl_Obj    *keylPtr,
+                       char       *key,
+                       Tcl_Obj   **listObjPtrPtr)
 {
     keylIntObj_t *keylIntPtr;
     Tcl_Obj *listObjPtr;
@@ -1017,11 +1005,10 @@ TclX_KeyedListGetKeys (interp, keylPtr, key, listObjPtrPtr)
  *-----------------------------------------------------------------------------
  */
 static int
-TclX_KeylgetObjCmd (clientData, interp, objc, objv)
-    ClientData	 clientData;
-    Tcl_Interp	*interp;
-    int		 objc;
-    Tcl_Obj	*CONST objv[];
+TclX_KeylgetObjCmd (ClientData      clientData,
+                    Tcl_Interp     *interp,
+                    int             objc,
+                    Tcl_Obj *CONST objv[])
 {
     Tcl_Obj *keylPtr, *valuePtr;
     char *key;
@@ -1096,11 +1083,10 @@ TclX_KeylgetObjCmd (clientData, interp, objc, objv)
  *-----------------------------------------------------------------------------
  */
 static int
-TclX_KeylsetObjCmd (clientData, interp, objc, objv)
-    ClientData	 clientData;
-    Tcl_Interp	*interp;
-    int		 objc;
-    Tcl_Obj	*CONST objv[];
+TclX_KeylsetObjCmd (ClientData     clientData,
+                    Tcl_Interp    *interp,
+                    int            objc,
+                    Tcl_Obj *CONST objv[])
 {
     Tcl_Obj *keylVarPtr, *newVarObj;
     char *key;
@@ -1156,11 +1142,10 @@ TclX_KeylsetObjCmd (clientData, interp, objc, objv)
  *----------------------------------------------------------------------------
  */
 static int
-TclX_KeyldelObjCmd (clientData, interp, objc, objv)
-    ClientData	 clientData;
-    Tcl_Interp	*interp;
-    int		 objc;
-    Tcl_Obj	*CONST objv[];
+TclX_KeyldelObjCmd (ClientData  clientData,
+                    Tcl_Interp *interp,
+                    int         objc,
+                    Tcl_Obj    *CONST objv[])
 {
     Tcl_Obj *keylVarPtr, *keylPtr;
     char *key;
@@ -1218,11 +1203,10 @@ TclX_KeyldelObjCmd (clientData, interp, objc, objv)
  *-----------------------------------------------------------------------------
  */
 static int
-TclX_KeylkeysObjCmd (clientData, interp, objc, objv)
-    ClientData	 clientData;
-    Tcl_Interp	*interp;
-    int		 objc;
-    Tcl_Obj	*CONST objv[];
+TclX_KeylkeysObjCmd (ClientData   clientData,
+                     Tcl_Interp  *interp,
+                     int          objc,
+                     Tcl_Obj     *CONST objv[])
 {
     Tcl_Obj *keylPtr, *listObjPtr;
     char *key;
@@ -1274,8 +1258,7 @@ TclX_KeylkeysObjCmd (clientData, interp, objc, objv)
  *-----------------------------------------------------------------------------
  */
 void
-TclX_KeyedListInit (interp)
-    Tcl_Interp *interp;
+TclX_KeyedListInit (Tcl_Interp *interp)
 {
     Tcl_RegisterObjType (&keyedListType);
 
@@ -1292,4 +1275,4 @@ TclX_KeyedListInit (interp)
 	    (ClientData) NULL, (Tcl_CmdDeleteProc*) NULL);
 }
 
-
+/* vim: set ts=8 sw=4 sts=4 et : */
