@@ -67,11 +67,8 @@ typedef struct profInfo_t {
     Tcl_Trace       traceHandle;           /* Handle to current trace.       */
     int             commandMode;           /* Prof all commands?             */
     int             evalMode;              /* Use eval stack.                */
-    Command        *currentCmdPtr;         /* Current command table entry.   */
-    Tcl_CmdProc    *savedStrCmdProc;       /* Saved string command function  */
-    ClientData      savedStrCmdClientData; /* and clientData.                */
-    Tcl_ObjCmdProc *savedObjCmdProc;       /* Saved object command function  */
-    ClientData      savedObjCmdClientData; /* and clientData.                */
+    Tcl_Command     currentCmd;            /* Current command table entry.   */
+    Tcl_CmdInfo     savedCmdInfo;          /* Details about the current cmd. */
     int             evalLevel;             /* Eval level when invoked.       */
     clock_t         realTime;              /* Current real and CPU time.     */
     clock_t         cpuTime;
@@ -86,90 +83,82 @@ typedef struct profInfo_t {
 } profInfo_t;
 
 /*
- * Argument to panic on logic errors.  Takes an id number.
+ * Argument to Tcl_Panic on logic errors.  Takes an id number.
  */
-static char *PROF_PANIC = "TclX profile bug id = %d\n";
+static const char *PROF_PANIC = "TclX profile bug id = %d\n";
 
 /*
  * Prototypes of internal functions.
  */
 static void
-PushEntry _ANSI_ARGS_((profInfo_t *infoPtr,
-                       char       *cmdName,
-                       int         isProc,
-                       int         procLevel,
-                       int         scopeLevel,
-                       int         evalLevel));
+PushEntry (profInfo_t *infoPtr,
+           const char *cmdName,
+           int         isProc,
+           int         procLevel,
+           int         scopeLevel,
+           int         evalLevel);
 
 static void
-RecordData _ANSI_ARGS_((profInfo_t  *infoPtr,
-                        profEntry_t *entryPtr));
+RecordData (profInfo_t  *infoPtr,
+            profEntry_t *entryPtr);
 
 static void
-PopEntry _ANSI_ARGS_((profInfo_t *infoPtr));
+PopEntry (profInfo_t *infoPtr);
 
 static void
-UpdateTOSTimes _ANSI_ARGS_((profInfo_t *infoPtr));
+UpdateTOSTimes (profInfo_t *infoPtr);
 
-static Command *
-ProfCommandEvalSetup _ANSI_ARGS_((profInfo_t *infoPtr,
-                                  int        *isProcPtr));
+static void
+ProfCommandEvalSetup (profInfo_t *infoPtr,
+                      int        *isProcPtr);
     
 static void
-ProfCommandEvalFinishup _ANSI_ARGS_((profInfo_t *infoPtr,
-                                     int         isProc));
+ProfCommandEvalFinishup (profInfo_t *infoPtr,
+                         int         isProc);
 
 static int
-ProfStrCommandEval _ANSI_ARGS_((ClientData    clientData,
-                                Tcl_Interp   *interp,
-                                int           argc,
-                                CONST84 char **argv));
+ProfStrCommandEval (ClientData    clientData,
+                    Tcl_Interp   *interp,
+                    int           argc,
+                    const char **argv);
 
 static int
-ProfObjCommandEval _ANSI_ARGS_((ClientData    clientData,
-                                Tcl_Interp   *interp,
-                                int           objc,
-                                Tcl_Obj      *CONST objv[]));
+ProfObjCommandEval (ClientData    clientData,
+                    Tcl_Interp   *interp,
+                    int           objc,
+                    Tcl_Obj      *CONST objv[]);
+
+static Tcl_CmdObjTraceProc ProfTraceRoutine;
 
 static void
-ProfTraceRoutine _ANSI_ARGS_((ClientData    clientData,
-                              Tcl_Interp   *interp,
-                              int           evalLevel,
-                              char         *command,
-                              Tcl_CmdProc  *cmdProc,
-                              ClientData    cmdClientData,
-                              int           argc,
-                              char        **argv));
+CleanDataTable (profInfo_t *infoPtr);
 
 static void
-CleanDataTable _ANSI_ARGS_((profInfo_t *infoPtr));
+InitializeProcStack (profInfo_t *infoPtr,
+                     CallFrame  *framePtr);
 
 static void
-InitializeProcStack _ANSI_ARGS_((profInfo_t *infoPtr,
-                                 CallFrame  *framePtr));
+TurnOnProfiling (profInfo_t *infoPtr,
+                 int         commandMode,
+                 int         evalMode);
 
 static void
-TurnOnProfiling _ANSI_ARGS_((profInfo_t *infoPtr,
-                             int         commandMode,
-                             int         evalMode));
-
-static void
-DeleteProfTrace _ANSI_ARGS_((profInfo_t *infoPtr));
+DeleteProfTrace (profInfo_t *infoPtr);
 
 static int
-TurnOffProfiling _ANSI_ARGS_((Tcl_Interp *interp,
-                              profInfo_t *infoPtr,
-                              char       *varName));
+TurnOffProfiling (Tcl_Interp *interp,
+                  profInfo_t *infoPtr,
+                  char       *varName);
 
 static int
-TclX_ProfileObjCmd _ANSI_ARGS_((ClientData   clientData,
-                                Tcl_Interp  *interp,
-                                int          objc,
-                                Tcl_Obj    *CONST objv[]));
+TclX_ProfileObjCmd (ClientData   clientData,
+                    Tcl_Interp  *interp,
+                    int          objc,
+                    Tcl_Obj    *CONST objv[]);
 
 static void
-ProfMonCleanUp _ANSI_ARGS_((ClientData  clientData,
-                            Tcl_Interp *interp));
+ProfMonCleanUp (ClientData  clientData,
+                Tcl_Interp *interp);
 
 
 /*-----------------------------------------------------------------------------
@@ -191,13 +180,12 @@ ProfMonCleanUp _ANSI_ARGS_((ClientData  clientData,
  *-----------------------------------------------------------------------------
  */
 static void
-PushEntry (infoPtr, cmdName, isProc, procLevel, scopeLevel, evalLevel)
-    profInfo_t *infoPtr;
-    char       *cmdName;
-    int         isProc;
-    int         procLevel;
-    int         scopeLevel;
-    int         evalLevel;
+PushEntry (profInfo_t *infoPtr,
+           const char *cmdName,
+           int         isProc,
+           int         procLevel,
+           int         scopeLevel,
+           int         evalLevel)
 {
     profEntry_t *entryPtr, *scanPtr;
 
@@ -240,7 +228,7 @@ PushEntry (infoPtr, cmdName, isProc, procLevel, scopeLevel, evalLevel)
          * Only global level can be NULL.
          */
         if (scanPtr == NULL)
-            panic (PROF_PANIC, 1);
+            Tcl_Panic (PROF_PANIC, 1);
     }
     entryPtr->prevScopePtr = scanPtr;
     infoPtr->scopeChainPtr = entryPtr;
@@ -256,9 +244,8 @@ PushEntry (infoPtr, cmdName, isProc, procLevel, scopeLevel, evalLevel)
  *-----------------------------------------------------------------------------
  */
 static void
-RecordData (infoPtr, entryPtr)
-    profInfo_t  *infoPtr;
-    profEntry_t *entryPtr;
+RecordData (profInfo_t  *infoPtr,
+            profEntry_t *entryPtr)
 {
     int idx, newEntry;
     profEntry_t *scanPtr;
@@ -284,7 +271,7 @@ RecordData (infoPtr, entryPtr)
             stackArgv [idx++] = scanPtr->cmdName;
         }
     }
-    stackListPtr = Tcl_Merge (idx, (CONST84 char **) stackArgv);
+    stackListPtr = Tcl_Merge (idx, (const char **) stackArgv);
     ckfree ((char *) stackArgv);
 
     /*
@@ -360,8 +347,7 @@ PopEntry (infoPtr)
  *-----------------------------------------------------------------------------
  */
 static void
-UpdateTOSTimes (infoPtr)
-    profInfo_t *infoPtr;
+UpdateTOSTimes (profInfo_t *infoPtr)
 {
     /*
      * Get the current time if we haven't already.
@@ -395,50 +381,48 @@ UpdateTOSTimes (infoPtr)
  *   A pointer to the current command table entry.
  *-----------------------------------------------------------------------------
  */
-static Command *
-ProfCommandEvalSetup (infoPtr, isProcPtr)
-    profInfo_t *infoPtr;
-    int        *isProcPtr;
+static void
+ProfCommandEvalSetup (profInfo_t *infoPtr, int *isProcPtr)
 {
     Interp *iPtr = (Interp *) infoPtr->interp;
-    Command *currentCmdPtr;
-    CallFrame *framePtr;
+    Tcl_CmdInfo cmdInfo;
     int procLevel, scopeLevel, isProc;
     Tcl_Obj *fullCmdNamePtr;
-    char *fullCmdName;
+    const char *fullCmdName;
 
+    Tcl_GetCommandInfoFromToken(infoPtr->currentCmd, &cmdInfo);
     /*
      * Restore the command table entry.  If the command has modified it, don't
      * mess with it.
      */
-    currentCmdPtr = infoPtr->currentCmdPtr;
-    if (currentCmdPtr->proc == ProfStrCommandEval)
-        currentCmdPtr->proc = infoPtr->savedStrCmdProc;
-    if (currentCmdPtr->clientData == (ClientData) infoPtr)
-        currentCmdPtr->clientData = infoPtr->savedStrCmdClientData;
-    if (currentCmdPtr->objProc == ProfObjCommandEval)
-        currentCmdPtr->objProc = infoPtr->savedObjCmdProc;
-    if (currentCmdPtr->objClientData == (ClientData) infoPtr)
-        currentCmdPtr->objClientData = infoPtr->savedObjCmdClientData;
-    infoPtr->currentCmdPtr = NULL;
-    infoPtr->savedStrCmdProc = NULL;
-    infoPtr->savedStrCmdClientData = NULL;
-    infoPtr->savedObjCmdProc = NULL;
-    infoPtr->savedObjCmdClientData = NULL;
+    if (cmdInfo.proc == ProfStrCommandEval)
+        cmdInfo.proc = infoPtr->savedCmdInfo.proc;
+    if (cmdInfo.clientData == (ClientData) infoPtr)
+        cmdInfo.clientData = infoPtr->savedCmdInfo.clientData;
+    if (cmdInfo.objProc == ProfObjCommandEval)
+        cmdInfo.objProc = infoPtr->savedCmdInfo.objProc;
+    if (cmdInfo.objClientData == (ClientData) infoPtr)
+        cmdInfo.objClientData = infoPtr->savedCmdInfo.objClientData;
+    if (cmdInfo.deleteProc == NULL)
+        cmdInfo.deleteProc = infoPtr->savedCmdInfo.deleteProc;
+    if (cmdInfo.deleteData == NULL)
+        cmdInfo.deleteData = infoPtr->savedCmdInfo.deleteData;
+    cmdInfo.isNativeObjectProc = infoPtr->savedCmdInfo.isNativeObjectProc;
+
+    Tcl_SetCommandInfoFromToken(infoPtr->currentCmd, &cmdInfo);
 
     fullCmdNamePtr = Tcl_NewObj ();
-    Tcl_GetCommandFullName (infoPtr->interp, (Tcl_Command) currentCmdPtr, 
+    Tcl_GetCommandFullName (infoPtr->interp, infoPtr->currentCmd, 
                             fullCmdNamePtr);
     fullCmdName = Tcl_GetStringFromObj (fullCmdNamePtr, NULL);
 
     /*
-     * Determine current proc and var levels.
+     * Use the level value passed in by Tcl_Interp through ProfTraceRoutine.
+     *   Ref: Tcl_CmdObjTraceProc(ClientData, Tcl_Interp*, int level, ...)
+     * The value calcuated from iPtr->framePtr chain may be smaller.
+     * And will cause issue when checking (infoPtr->stackPtr->procLevel > procLevel).
      */
-    procLevel = 0;
-    for (framePtr = iPtr->framePtr; framePtr != NULL; framePtr =
-             framePtr->callerPtr) {
-        procLevel++;
-    }
+    procLevel = infoPtr->evalLevel;
     scopeLevel = (iPtr->varFramePtr == NULL) ? 0 : iPtr->varFramePtr->level;
 
     /* 
@@ -446,12 +430,13 @@ ProfCommandEvalSetup (infoPtr, isProcPtr)
      * than we are, we have exited into the initial entries that where pushed
      * on the stack before we started.  Pop those entries.
      */
-    if (infoPtr->stackPtr->procLevel > procLevel)
+    if (infoPtr->stackPtr->procLevel > procLevel) {
         UpdateTOSTimes (infoPtr);
-    while (infoPtr->stackPtr->procLevel > procLevel) {
-        if (infoPtr->stackPtr->evalLevel != UNKNOWN_LEVEL) 
-            panic (PROF_PANIC, 2);  /* Not an initial entry */
-        PopEntry (infoPtr);
+        do {
+            if (infoPtr->stackPtr->evalLevel != UNKNOWN_LEVEL) 
+                Tcl_Panic (PROF_PANIC, 2);  /* Not an initial entry */
+            PopEntry (infoPtr);
+        } while (infoPtr->stackPtr->procLevel > procLevel);
     }
 
     /*
@@ -478,7 +463,6 @@ ProfCommandEvalSetup (infoPtr, isProcPtr)
     *isProcPtr = isProc;
 
     Tcl_DecrRefCount (fullCmdNamePtr);
-    return currentCmdPtr;
 }
 
 /*-----------------------------------------------------------------------------
@@ -488,9 +472,7 @@ ProfCommandEvalSetup (infoPtr, isProcPtr)
  *-----------------------------------------------------------------------------
  */
 static void
-ProfCommandEvalFinishup (infoPtr, isProc)
-    profInfo_t *infoPtr;
-    int         isProc;
+ProfCommandEvalFinishup (profInfo_t *infoPtr, int isProc)
 {
     /*
      * If tracing is still running, pop the entry, recording the information.
@@ -520,19 +502,17 @@ ProfCommandEvalFinishup (infoPtr, isProc)
  *-----------------------------------------------------------------------------
  */
 static int
-ProfStrCommandEval (clientData, interp, argc, argv)
-    ClientData    clientData;
-    Tcl_Interp   *interp;
-    int           argc;
-    CONST84 char **argv;
+ProfStrCommandEval (ClientData    clientData,
+                    Tcl_Interp   *interp,
+                    int           argc,
+                    const char **argv)
 {
     profInfo_t *infoPtr = (profInfo_t *) clientData;
-    Command *currentCmdPtr;
     int isProc, result;
 
-    currentCmdPtr = ProfCommandEvalSetup (infoPtr, &isProc);
+    ProfCommandEvalSetup (infoPtr, &isProc);
 
-    result = (*currentCmdPtr->proc) (currentCmdPtr->clientData, interp,
+    result = (*infoPtr->savedCmdInfo.proc)(infoPtr->savedCmdInfo.clientData, interp,
                                      argc, argv);
 
     ProfCommandEvalFinishup (infoPtr, isProc);
@@ -552,20 +532,17 @@ ProfStrCommandEval (clientData, interp, argc, argv)
  *-----------------------------------------------------------------------------
  */
 static int
-ProfObjCommandEval (clientData, interp, objc, objv)
-    ClientData    clientData;
-    Tcl_Interp   *interp;
-    int           objc;
-    Tcl_Obj     *CONST objv[];
+ProfObjCommandEval (ClientData    clientData,
+                    Tcl_Interp   *interp,
+                    int           objc,
+                    Tcl_Obj      *CONST objv[])
 {
     profInfo_t *infoPtr = (profInfo_t *) clientData;
-    Command *currentCmdPtr;
     int isProc, result;
 
-    currentCmdPtr = ProfCommandEvalSetup (infoPtr,
-                                          &isProc);
+    ProfCommandEvalSetup (infoPtr, &isProc);
 
-    result = (*currentCmdPtr->objProc) (currentCmdPtr->objClientData, interp,
+    result = (*infoPtr->savedCmdInfo.objProc)(infoPtr->savedCmdInfo.objClientData, interp,
                                         objc, objv);
 
     ProfCommandEvalFinishup (infoPtr, isProc);
@@ -578,56 +555,46 @@ ProfObjCommandEval (clientData, interp, objc, objv)
  * command being executed by temporarily editing the command table.
  *-----------------------------------------------------------------------------
  */
-static void
-ProfTraceRoutine (clientData, interp, evalLevel, command, cmdProc,
-                  cmdClientData, argc, argv)
-    ClientData    clientData;
-    Tcl_Interp   *interp;
-    int           evalLevel;
-    char         *command;
-    Tcl_CmdProc  *cmdProc;
-    ClientData    cmdClientData;
-    int           argc;
-    char        **argv;
+static int
+ProfTraceRoutine (ClientData  clientData,
+                  Tcl_Interp *interp,
+                  int         evalLevel,
+                  const char *command,
+                  Tcl_Command cmd,
+                  int         objc,
+                  Tcl_Obj    *CONST objv[])
 {
+    /* struct Tcl_Obj * const *objv; */
     profInfo_t *infoPtr = (profInfo_t *) clientData;
-    Command *cmdPtr;
-    Tcl_Command cmd;
+    Tcl_CmdInfo cmdInfo;
 
-    if (infoPtr->currentCmdPtr != NULL)
-        panic (PROF_PANIC, 3);
-
-    cmd = Tcl_FindCommand (interp, argv [0], NULL, 0);
     if (cmd == NULL)
-        panic (PROF_PANIC, 4);
-    cmdPtr = (Command *) cmd;
-
-    if ((cmdPtr->proc != cmdProc) || (cmdPtr->clientData != cmdClientData))
-        panic (PROF_PANIC, 5);
-
-    /*
-     * If command is to be compiled, we can't profile it.
-     */
-    if (cmdPtr->compileProc != NULL)
-        return;
+        Tcl_Panic (PROF_PANIC, 4);
 
+    //TIP #571: We don' want to profile the tailcall itself. As it can only be called in a procedure/lambda context
+    if ( ! strcmp((*objv)->bytes, "tailcall") ) {
+        return TCL_OK;
+    }
     /*
      * Save current state information.
      */
-    infoPtr->currentCmdPtr = cmdPtr;
-    infoPtr->savedStrCmdProc = cmdPtr->proc;
-    infoPtr->savedStrCmdClientData = cmdPtr->clientData;
-    infoPtr->savedObjCmdProc = cmdPtr->objProc;
-    infoPtr->savedObjCmdClientData = cmdPtr->objClientData;
+    Tcl_GetCommandInfoFromToken(cmd, &(infoPtr->savedCmdInfo));
     infoPtr->evalLevel = evalLevel;
+    infoPtr->currentCmd = cmd;
 
     /*
      * Force our routines to be called.
      */
-    cmdPtr->proc = ProfStrCommandEval;
-    cmdPtr->clientData = (ClientData) infoPtr;
-    cmdPtr->objProc = ProfObjCommandEval;
-    cmdPtr->objClientData = (ClientData) infoPtr;
+    cmdInfo.proc = ProfStrCommandEval;
+    cmdInfo.clientData = (ClientData) infoPtr;
+    cmdInfo.objProc = ProfObjCommandEval;
+    cmdInfo.objClientData = (ClientData) infoPtr;
+    cmdInfo.isNativeObjectProc = infoPtr->savedCmdInfo.isNativeObjectProc;
+    cmdInfo.deleteProc = NULL;
+    cmdInfo.deleteData = NULL;
+    Tcl_SetCommandInfoFromToken(cmd, &cmdInfo);
+
+    return TCL_OK;
 }
 
 /*-----------------------------------------------------------------------------
@@ -640,8 +607,7 @@ ProfTraceRoutine (clientData, interp, evalLevel, command, cmdProc,
  *-----------------------------------------------------------------------------
  */
 static void
-CleanDataTable (infoPtr)
-    profInfo_t *infoPtr;
+CleanDataTable (profInfo_t *infoPtr)
 {
     Tcl_HashEntry    *hashEntryPtr;
     Tcl_HashSearch   searchCookie;
@@ -669,9 +635,7 @@ CleanDataTable (infoPtr)
  *-----------------------------------------------------------------------------
  */
 static void
-InitializeProcStack (infoPtr, framePtr)
-    profInfo_t *infoPtr;
-    CallFrame  *framePtr;
+InitializeProcStack (profInfo_t *infoPtr, CallFrame *framePtr)
 {
     if (framePtr == NULL || framePtr->objv == NULL)
         return;
@@ -699,10 +663,7 @@ InitializeProcStack (infoPtr, framePtr)
  *-----------------------------------------------------------------------------
  */
 static void
-TurnOnProfiling (infoPtr, commandMode, evalMode)
-    profInfo_t *infoPtr;
-    int         commandMode;
-    int         evalMode;
+TurnOnProfiling (profInfo_t *infoPtr, int commandMode, int evalMode)
 {
     Interp *iPtr = (Interp *) infoPtr->interp;
     int scopeLevel;
@@ -711,9 +672,9 @@ TurnOnProfiling (infoPtr, commandMode, evalMode)
     CleanDataTable (infoPtr);
 
     infoPtr->traceHandle =
-        Tcl_CreateTrace (infoPtr->interp, MAXINT,
-                         (Tcl_CmdTraceProc *) ProfTraceRoutine,
-                         (ClientData) infoPtr);
+        Tcl_CreateObjTrace (infoPtr->interp, 0,
+                         TCL_ALLOW_INLINE_COMPILATION, ProfTraceRoutine,
+                         (ClientData) infoPtr, NULL);
     infoPtr->commandMode = commandMode;
     infoPtr->evalMode = evalMode;
     infoPtr->realTime = 0;
@@ -740,7 +701,7 @@ TurnOnProfiling (infoPtr, commandMode, evalMode)
          * Only global level can be NULL.
          */
         if (scanPtr == NULL)
-            panic (PROF_PANIC, 6);
+            Tcl_Panic (PROF_PANIC, 6);
     }
     infoPtr->scopeChainPtr = scanPtr;
 
@@ -760,8 +721,7 @@ TurnOnProfiling (infoPtr, commandMode, evalMode)
  *-----------------------------------------------------------------------------
  */
 static void
-DeleteProfTrace (infoPtr)
-    profInfo_t *infoPtr;
+DeleteProfTrace (profInfo_t *infoPtr)
 {
     Tcl_DeleteTrace (infoPtr->interp, infoPtr->traceHandle);
     infoPtr->traceHandle = NULL;
@@ -787,15 +747,12 @@ DeleteProfTrace (infoPtr)
  *-----------------------------------------------------------------------------
  */
 static int
-TurnOffProfiling (interp, infoPtr, varName)
-    Tcl_Interp *interp;
-    profInfo_t *infoPtr;
-    char       *varName;
+TurnOffProfiling (Tcl_Interp *interp, profInfo_t *infoPtr, char *varName)
 {
     Tcl_HashEntry *hashEntryPtr;
     Tcl_HashSearch searchCookie;
     profDataEntry_t *dataEntryPtr;
-    CONST84 char *dataArgv [3];
+    const char *dataArgv [3];
     char countBuf [32], realTimeBuf [32], cpuTimeBuf [32], *dataListPtr;
 
     DeleteProfTrace (infoPtr);
@@ -842,11 +799,10 @@ TurnOffProfiling (interp, infoPtr, varName)
  *-----------------------------------------------------------------------------
  */
 static int
-TclX_ProfileObjCmd (clientData, interp, objc, objv)
-    ClientData   clientData;
-    Tcl_Interp  *interp;
-    int          objc;
-    Tcl_Obj    *CONST objv[];
+TclX_ProfileObjCmd (ClientData   clientData,
+                    Tcl_Interp  *interp,
+                    int          objc,
+                    Tcl_Obj    *CONST objv[])
 {
     profInfo_t *infoPtr = (profInfo_t *) clientData;
     int argIdx;
@@ -943,9 +899,7 @@ TclX_ProfileObjCmd (clientData, interp, objc, objv)
  *-----------------------------------------------------------------------------
  */
 static void
-ProfMonCleanUp (clientData, interp)
-    ClientData  clientData;
-    Tcl_Interp *interp;
+ProfMonCleanUp (ClientData clientData, Tcl_Interp *interp)
 {
     profInfo_t *infoPtr = (profInfo_t *) clientData;
 
@@ -962,8 +916,7 @@ ProfMonCleanUp (clientData, interp)
  *-----------------------------------------------------------------------------
  */
 void
-TclX_ProfileInit (interp)
-    Tcl_Interp *interp;
+TclX_ProfileInit (Tcl_Interp *interp)
 {
     profInfo_t *infoPtr;
 
@@ -973,11 +926,7 @@ TclX_ProfileInit (interp)
     infoPtr->traceHandle = NULL;
     infoPtr->commandMode = FALSE;
     infoPtr->evalMode = FALSE;
-    infoPtr->currentCmdPtr = NULL;
-    infoPtr->savedStrCmdProc = NULL;
-    infoPtr->savedStrCmdClientData = NULL;
-    infoPtr->savedObjCmdProc = NULL;
-    infoPtr->savedObjCmdClientData = NULL;
+    infoPtr->currentCmd = NULL;
     infoPtr->evalLevel = UNKNOWN_LEVEL;
     infoPtr->realTime = 0;
     infoPtr->cpuTime = 0;
@@ -998,5 +947,4 @@ TclX_ProfileInit (interp)
 			  (Tcl_CmdDeleteProc*) NULL);
 }
 
-
-
+/* vim: set ts=4 sw=4 sts=4 et : */
