@@ -18,7 +18,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXselect.c,v 1.5 2005/04/26 20:01:34 hobbs Exp $
+ * $Id: tclXselect.c,v 1.6 2005/07/12 19:03:15 hobbs Exp $
  *-----------------------------------------------------------------------------
  */
 
@@ -42,36 +42,45 @@
 typedef struct {
     Tcl_Obj     *channelIdObj;
     Tcl_Channel  channel;
+#ifdef WIN32
+    /*
+     * XXX Not strictly correct, according to TclX's usage of fds, but we
+     * XXX expect noone to really being using select hardcore on Windows
+     */
     unsigned int readFd;
     unsigned int writeFd;
+#else
+    int readFd;
+    int writeFd;
+#endif
 } channelData_t;
 
 /*
  * Prototypes of internal functions.
  */
 static int
-ParseSelectFileList _ANSI_ARGS_((Tcl_Interp     *interp,
-                                 int             chanAccess,
-                                 Tcl_Obj        *handleList,
-                                 fd_set         *fileSetPtr,
-                                 channelData_t **channelListPtr,
-                                 int            *maxFileIdPtr));
+ParseSelectFileList (Tcl_Interp     *interp,
+                     int             chanAccess,
+                     Tcl_Obj        *handleList,
+                     fd_set         *fileSetPtr,
+                     channelData_t **channelListPtr,
+                     int            *maxFileIdPtr);
 
 static int
-FindPendingData _ANSI_ARGS_((int            fileDescCnt,
-                             channelData_t *channelList,
-                             fd_set        *fileDescSetPtr));
+FindPendingData (int            fileDescCnt,
+                 channelData_t *channelList,
+                 fd_set        *fileDescSetPtr);
 
 static Tcl_Obj *
-ReturnSelectedFileList _ANSI_ARGS_((fd_set        *fileDescSetPtr,
-                                    int            fileDescCnt,
-                                    channelData_t *channelListPtr));
+ReturnSelectedFileList (fd_set        *fileDescSetPtr,
+                        int            fileDescCnt,
+                        channelData_t *channelListPtr);
 
 static int 
-TclX_SelectObjCmd _ANSI_ARGS_((ClientData clientData, 
-                               Tcl_Interp *interp,
-                               int objc,
-                               Tcl_Obj *CONST objv[]));
+TclX_SelectObjCmd (ClientData clientData, 
+                   Tcl_Interp *interp,
+                   int objc,
+                   Tcl_Obj *CONST objv[]);
 
 
 /*-----------------------------------------------------------------------------
@@ -98,14 +107,12 @@ TclX_SelectObjCmd _ANSI_ARGS_((ClientData clientData,
  *-----------------------------------------------------------------------------
  */
 static int
-ParseSelectFileList (interp, chanAccess, handleList, fileSetPtr,
-                     channelListPtr, maxFileIdPtr)
-    Tcl_Interp    *interp;
-    int            chanAccess;
-    Tcl_Obj       *handleList;
-    fd_set        *fileSetPtr;
-    channelData_t **channelListPtr;
-    int           *maxFileIdPtr;
+ParseSelectFileList (Tcl_Interp     *interp,
+                     int             chanAccess,
+                     Tcl_Obj        *handleList,
+                     fd_set         *fileSetPtr,
+                     channelData_t **channelListPtr,
+                     int            *maxFileIdPtr)
 {
     int handleCnt, idx;
     Tcl_Obj **handleObjv;
@@ -195,10 +202,9 @@ ParseSelectFileList (interp, chanAccess, handleList, fileSetPtr,
  *-----------------------------------------------------------------------------
  */
 static int
-FindPendingData (fileDescCnt, channelList, fileDescSetPtr)
-    int            fileDescCnt;
-    channelData_t *channelList;
-    fd_set        *fileDescSetPtr;
+FindPendingData (int            fileDescCnt,
+                 channelData_t *channelList,
+                 fd_set        *fileDescSetPtr)
 {
     int idx, found = FALSE;
 
@@ -229,10 +235,9 @@ FindPendingData (fileDescCnt, channelList, fileDescSetPtr)
  *-----------------------------------------------------------------------------
  */
 static Tcl_Obj *
-ReturnSelectedFileList (fileDescSetPtr, fileDescCnt, channelList) 
-    fd_set        *fileDescSetPtr;
-    int            fileDescCnt;
-    channelData_t *channelList;
+ReturnSelectedFileList (fd_set        *fileDescSetPtr,
+                        int            fileDescCnt,
+                        channelData_t *channelList)
 {
     int idx, handleCnt;
     Tcl_Obj *fileHandleList = Tcl_NewListObj (0, NULL);
@@ -266,12 +271,11 @@ ReturnSelectedFileList (fileDescSetPtr, fileDescCnt, channelList)
  *     or {} it the timeout expired.
  *-----------------------------------------------------------------------------
  */
-static int
-TclX_SelectObjCmd (clientData, interp, objc, objv)
-    ClientData   clientData;
-    Tcl_Interp  *interp;
-    int          objc;
-    Tcl_Obj     *CONST objv[];
+static int 
+TclX_SelectObjCmd (ClientData clientData, 
+                   Tcl_Interp *interp,
+                   int objc,
+                   Tcl_Obj *CONST objv[])
 {
     static int chanAccess [] = {TCL_READABLE, TCL_WRITABLE, 0};
     int idx;
@@ -402,7 +406,7 @@ TclX_SelectObjCmd (clientData, interp, objc, objv)
     ClientData   clientData;
     Tcl_Interp  *interp;
     int          objc;
-    Tcl_Obj     *CONST objv[];
+    Tcl_Obj     *CONST objv[]
 {
     Tcl_AppendResult(interp, Tcl_GetString(objv[0]),
 	    " is not available on this OS", (char *) NULL);
@@ -417,8 +421,7 @@ TclX_SelectObjCmd (clientData, interp, objc, objv)
  *-----------------------------------------------------------------------------
  */
 void
-TclX_SelectInit (interp)
-    Tcl_Interp *interp;
+TclX_SelectInit (Tcl_Interp *interp)
 {
     Tcl_CreateObjCommand (interp, 
                           "select",
@@ -427,3 +430,5 @@ TclX_SelectInit (interp)
                           (Tcl_CmdDeleteProc*) NULL);
 }
 
+
+/* vim: set ts=4 sw=4 sts=4 et : */
