@@ -12,7 +12,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXunixId.c,v 8.1 2001/10/24 23:31:50 hobbs Exp $
+ * $Id: tclXunixId.c,v 8.9 1999/12/03 03:02:08 markd Exp $
  *-----------------------------------------------------------------------------
  */
 
@@ -38,76 +38,76 @@ static int confNGroups = NGROUPS;
  * Prototypes of internal functions.
  */
 static int
-UseridToUsernameResult _ANSI_ARGS_((Tcl_Interp *interp,
-                                    int         userId));
+UseridToUsernameResult (Tcl_Interp *interp,
+                        int         userId);
 
 static int
-UsernameToUseridResult _ANSI_ARGS_((Tcl_Interp *interp,
-                                    char       *userName));
+UsernameToUseridResult (Tcl_Interp *interp,
+                        char       *userName);
 
 static int
-GroupidToGroupnameResult _ANSI_ARGS_((Tcl_Interp *interp,
-                                      int         groupId));
+GroupidToGroupnameResult (Tcl_Interp *interp,
+                          int         groupId);
 
 static int
-GroupnameToGroupidResult _ANSI_ARGS_((Tcl_Interp *interp,
-                                      char       *groupName));
+GroupnameToGroupidResult (Tcl_Interp *interp,
+                          char       *groupName);
 
 static int
-IdConvert _ANSI_ARGS_((Tcl_Interp *interp,
-                       int         objc,
-                       Tcl_Obj   *CONST objv[]));
+IdConvert (Tcl_Interp *interp,
+           int         objc,
+           Tcl_Obj   *CONST objv[]);
 
 static int
-IdEffective  _ANSI_ARGS_((Tcl_Interp  *interp,
-                          int          objc,
-                          Tcl_Obj      *CONST objv[]));
+IdEffective  (Tcl_Interp  *interp,
+              int          objc,
+              Tcl_Obj      *CONST objv[]);
 
 static int
-IdProcess  _ANSI_ARGS_((Tcl_Interp    *interp,
-                        int            objc,
-                        Tcl_Obj      *CONST objv[]));
+IdProcess  (Tcl_Interp    *interp,
+            int            objc,
+            Tcl_Obj      *CONST objv[]);
 
 static int
-IdGroupids  _ANSI_ARGS_((Tcl_Interp    *interp,
-                         int            objc,
-                         Tcl_Obj      *CONST objv[],
-                         int         symbolic));
+IdGroupids  (Tcl_Interp    *interp,
+             int            objc,
+             Tcl_Obj      *CONST objv[],
+             int         symbolic);
 
 static int
-IdHost _ANSI_ARGS_((Tcl_Interp    *interp,
-                    int            objc,
-                    Tcl_Obj      *CONST objv[]));
+IdHost (Tcl_Interp    *interp,
+        int            objc,
+        Tcl_Obj      *CONST objv[]);
 
 static int
-GetSetWrongArgs _ANSI_ARGS_((Tcl_Interp    *interp,
-                             Tcl_Obj      *CONST objv[]));
+GetSetWrongArgs (Tcl_Interp    *interp,
+                 Tcl_Obj      *CONST objv[]);
 
 static int
-IdUser _ANSI_ARGS_((Tcl_Interp    *interp,
-                    int            objc,
-                    Tcl_Obj      *CONST objv[]));
+IdUser (Tcl_Interp    *interp,
+        int            objc,
+        Tcl_Obj      *CONST objv[]);
 
 static int
-IdUserId _ANSI_ARGS_((Tcl_Interp    *interp,
-                      int            objc,
-                      Tcl_Obj      *CONST objv[]));
+IdUserId (Tcl_Interp    *interp,
+          int            objc,
+          Tcl_Obj      *CONST objv[]);
 
 static int
-IdGroup _ANSI_ARGS_((Tcl_Interp    *interp,
-                     int            objc,
-                     Tcl_Obj      *CONST objv[]));
+IdGroup (Tcl_Interp    *interp,
+         int            objc,
+         Tcl_Obj      *CONST objv[]);
 
 static int
-IdGroupId _ANSI_ARGS_((Tcl_Interp    *interp,
-                       int            objc,
-                       Tcl_Obj      *CONST objv[]));
+IdGroupId (Tcl_Interp    *interp,
+           int            objc,
+           Tcl_Obj      *CONST objv[]);
 
 static int 
-TclX_IdObjCmd _ANSI_ARGS_((ClientData clientData,
-                           Tcl_Interp *interp,
-                           int objc,
-                           Tcl_Obj *CONST objv[]));
+TclX_IdObjCmd (ClientData clientData,
+               Tcl_Interp *interp,
+               int objc,
+               Tcl_Obj *CONST objv[]);
 
 /*-----------------------------------------------------------------------------
  * TclX_IdObjCmd --
@@ -147,9 +147,8 @@ TclX_IdObjCmd _ANSI_ARGS_((ClientData clientData,
  */
 
 static int
-UseridToUsernameResult (interp, userId)
-    Tcl_Interp *interp;
-    int         userId;
+UseridToUsernameResult (Tcl_Interp *interp,
+                        int         userId)
 {
     uid_t          uid = (uid_t) userId;
     struct passwd *pw = getpwuid (userId);
@@ -171,9 +170,7 @@ UseridToUsernameResult (interp, userId)
 }
 
 static int
-UsernameToUseridResult (interp, userName)
-    Tcl_Interp *interp;
-    char       *userName;
+UsernameToUseridResult (Tcl_Interp *interp, char *userName)
 {
     struct passwd *pw = getpwnam (userName);
     Tcl_Obj       *resultObj = Tcl_GetObjResult (interp);
@@ -192,9 +189,7 @@ UsernameToUseridResult (interp, userName)
 }
 
 static int
-GroupidToGroupnameResult (interp, groupId)
-    Tcl_Interp *interp;
-    int         groupId;
+GroupidToGroupnameResult (Tcl_Interp *interp, int groupId)
 {
     gid_t          gid = (gid_t) groupId;
     struct group  *grp = getgrgid (groupId);
@@ -217,9 +212,7 @@ GroupidToGroupnameResult (interp, groupId)
 }
 
 static int
-GroupnameToGroupidResult (interp, groupName)
-    Tcl_Interp *interp;
-    char       *groupName;
+GroupnameToGroupidResult (Tcl_Interp *interp, char *groupName)
 {
     struct group  *grp = getgrnam (groupName);
     Tcl_Obj       *resultObj = Tcl_GetObjResult (interp);
@@ -238,10 +231,7 @@ GroupnameToGroupidResult (interp, groupName)
  * id convert type value
  */
 static int
-IdConvert (interp, objc, objv)
-    Tcl_Interp    *interp;
-    int            objc;
-    Tcl_Obj      *CONST objv[];
+IdConvert (Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
     long           uid;
     long           gid;
@@ -282,10 +272,7 @@ IdConvert (interp, objc, objv)
  * id effective type
  */
 static int
-IdEffective (interp, objc, objv)
-    Tcl_Interp    *interp;
-    int            objc;
-    Tcl_Obj      *CONST objv[];
+IdEffective (Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
     char          *subCommand;
 
@@ -320,10 +307,7 @@ IdEffective (interp, objc, objv)
  * id process ?parent|group? ?set?
  */
 static int
-IdProcess (interp, objc, objv)
-    Tcl_Interp    *interp;
-    int            objc;
-    Tcl_Obj      *CONST objv[];
+IdProcess (Tcl_Interp *interp, int objc, Tcl_Obj      *CONST objv[])
 {
     pid_t          pid;
     char          *subCommand;
@@ -384,11 +368,7 @@ IdProcess (interp, objc, objv)
  * id groups
  */
 static int
-IdGroupids (interp, objc, objv, symbolic)
-    Tcl_Interp    *interp;
-    int            objc;
-    Tcl_Obj      *CONST objv[];
-    int            symbolic;
+IdGroupids (Tcl_Interp *interp, int objc, Tcl_Obj*CONST objv[], int symbolic)
 {
 #ifndef NO_GETGROUPS
     gid_t         *groups;
@@ -456,10 +436,7 @@ IdGroupids (interp, objc, objv, symbolic)
  * id host
  */
 static int
-IdHost (interp, objc, objv)
-    Tcl_Interp    *interp;
-    int            objc;
-    Tcl_Obj      *CONST objv[];
+IdHost (Tcl_Interp *interp, int objc, Tcl_Obj*CONST objv[])
 {
 #ifndef NO_GETHOSTNAME
 #ifndef MAXHOSTNAMELEN
@@ -470,18 +447,18 @@ IdHost (interp, objc, objv)
     if (objc != 2)
         return TclX_WrongArgs (interp, objv [0], "host");
 
-	if (gethostname (hostNameBuf, MAXHOSTNAMELEN) < 0) {
-            TclX_AppendObjResult (interp, Tcl_PosixError (interp),
-                                  (char *) NULL);
-	    return TCL_ERROR;
-	}
-	hostNameBuf[MAXHOSTNAMELEN-1] = '\0';
-	Tcl_SetObjResult (interp, Tcl_NewStringObj (hostNameBuf, -1));
-	return TCL_OK;
-#else
-        TclX_AppendObjResult (interp, "host name unavailable on this system ",
-                              "(no gethostname function)", (char *) NULL);
+    if (gethostname (hostNameBuf, MAXHOSTNAMELEN) < 0) {
+        TclX_AppendObjResult (interp, Tcl_PosixError (interp),
+                              (char *) NULL);
         return TCL_ERROR;
+    }
+    hostNameBuf[MAXHOSTNAMELEN-1] = '\0';
+    Tcl_SetObjResult (interp, Tcl_NewStringObj (hostNameBuf, -1));
+    return TCL_OK;
+#else
+    TclX_AppendObjResult (interp, "host name unavailable on this system ",
+                              "(no gethostname function)", (char *) NULL);
+    return TCL_ERROR;
 #endif
 }
 
@@ -489,9 +466,7 @@ IdHost (interp, objc, objv)
  * Return error when a get set function has too many args (2 or 3 expected).
  */
 static int
-GetSetWrongArgs (interp, objv)
-    Tcl_Interp    *interp;
-    Tcl_Obj      *CONST objv[];
+GetSetWrongArgs (Tcl_Interp *interp, Tcl_Obj*CONST objv[])
 {
     return TclX_WrongArgs (interp, objv [0], "arg ?value?");
 }
@@ -500,10 +475,7 @@ GetSetWrongArgs (interp, objv)
  * id user
  */
 static int
-IdUser (interp, objc, objv)
-    Tcl_Interp *interp;
-    int            objc;
-    Tcl_Obj      *CONST objv[];
+IdUser (Tcl_Interp *interp, int objc, Tcl_Obj*CONST objv[])
 {
     struct passwd *pw;
     char          *user;
@@ -539,10 +511,7 @@ IdUser (interp, objc, objv)
  * id userid
  */
 static int
-IdUserId (interp, objc, objv)
-    Tcl_Interp    *interp;
-    int            objc;
-    Tcl_Obj      *CONST objv[];
+IdUserId (Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
     int uid;
 
@@ -569,10 +538,7 @@ IdUserId (interp, objc, objv)
  * id group
  */
 static int
-IdGroup (interp, objc, objv)
-    Tcl_Interp    *interp;
-    int            objc;
-    Tcl_Obj      *CONST objv[];
+IdGroup (Tcl_Interp *interp, int objc, Tcl_Obj*CONST objv[])
 {
     struct group *grp;
     char         *groupName;
@@ -608,10 +574,7 @@ IdGroup (interp, objc, objv)
  * id groupid
  */
 static int
-IdGroupId (interp, objc, objv)
-    Tcl_Interp    *interp;
-    int            objc;
-    Tcl_Obj      *CONST objv[];
+IdGroupId (Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
     int gid;
     
@@ -635,11 +598,7 @@ IdGroupId (interp, objc, objv)
 }
 
 static int
-TclX_IdObjCmd (clientData, interp, objc, objv)
-    ClientData  clientData;
-    Tcl_Interp *interp;
-    int         objc;
-    Tcl_Obj   *CONST objv[];
+TclX_IdObjCmd (ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj*CONST objv[])
 {
     char       *subCommand;
 
@@ -722,8 +681,7 @@ TclX_IdObjCmd (clientData, interp, objc, objv)
  *-----------------------------------------------------------------------------
  */
 void
-TclX_IdInit (interp)
-    Tcl_Interp *interp;
+TclX_IdInit (Tcl_Interp *interp)
 {
     Tcl_CreateObjCommand (interp,
 			  "id",
@@ -731,3 +689,5 @@ TclX_IdInit (interp)
                           (ClientData) NULL,
 			  (Tcl_CmdDeleteProc*) NULL);
 }
+
+/* vim: set ts=4 sw=4 sts=4 et : */
