@@ -17,16 +17,26 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXunixOS.c,v 8.6 2005/04/26 20:01:34 hobbs Exp $
+ * $Id: tclXunixOS.c,v 8.8 2005/07/08 00:44:33 hobbs Exp $
  *-----------------------------------------------------------------------------
  */
 
 #include "tclExtdInt.h"
+#include <stdint.h>
 
 #ifndef NO_GETPRIORITY
 #include <sys/resource.h>
 #endif
 
+/*
+ * Tcl 8.4 had some weird and unnecessary ifdef'ery for readdir
+ * readdir() should be thread-safe according to the Single Unix Spec.
+ * [Bug #1095909]
+ */
+#ifdef readdir
+#undef readdir
+#endif
+
 /*
  * Cheat a little to avoid configure checking for floor and ceil being
  * This breaks with GNU libc headers...really should check with autoconf.
@@ -43,16 +53,16 @@ double ceil ();
  * Prototypes of internal functions.
  */
 static int
-ChannelToFnum _ANSI_ARGS_((Tcl_Channel channel,
-                           int         direction));
+ChannelToFnum (Tcl_Channel channel,
+               int         direction);
 
 static int
-ConvertOwnerGroup _ANSI_ARGS_((Tcl_Interp  *interp,
-                               unsigned     options,
-                               char        *ownerStr,
-                               char        *groupStr,
-                               uid_t       *ownerId,
-                               gid_t       *groupId));
+ConvertOwnerGroup (Tcl_Interp  *interp,
+                   unsigned     options,
+                   char        *ownerStr,
+                   char        *groupStr,
+                   uid_t       *ownerId,
+                   gid_t       *groupId);
 
 
 /*-----------------------------------------------------------------------------
@@ -67,9 +77,7 @@ ConvertOwnerGroup _ANSI_ARGS_((Tcl_Interp  *interp,
  *-----------------------------------------------------------------------------
  */
 int
-TclXNotAvailableError (interp, funcName)
-    Tcl_Interp *interp;
-    char       *funcName;
+TclXNotAvailableError (Tcl_Interp *interp, char *funcName)
 {
     TclX_AppendObjResult (interp, funcName, " is not available on this system",
                           (char *) NULL);
@@ -92,9 +100,7 @@ TclXNotAvailableError (interp, funcName)
  *-----------------------------------------------------------------------------
  */
 static int
-ChannelToFnum (channel, direction)
-    Tcl_Channel channel;
-    int         direction;
+ChannelToFnum (Tcl_Channel channel, int direction)
 {
     ClientData handle;
 
@@ -108,7 +114,7 @@ ChannelToFnum (channel, direction)
             return -1;
 	}
     }
-    return (int) handle;
+    return (intptr_t) handle;
 }
 
 /*-----------------------------------------------------------------------------
@@ -123,8 +129,7 @@ ChannelToFnum (channel, direction)
  *-----------------------------------------------------------------------------
  */
 clock_t
-TclXOSTicksToMS (numTicks)
-    clock_t numTicks;
+TclXOSTicksToMS (clock_t numTicks)
 {
     static clock_t msPerTick = 0;
 
@@ -164,10 +169,7 @@ TclXOSTicksToMS (numTicks)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSgetpriority (interp, priority, funcName)
-    Tcl_Interp *interp;
-    int        *priority;
-    char       *funcName;
+TclXOSgetpriority (Tcl_Interp *interp, int *priority, char *funcName)
 {
 #ifndef NO_GETPRIORITY
     *priority = getpriority (PRIO_PROCESS, 0);
@@ -191,11 +193,7 @@ TclXOSgetpriority (interp, priority, funcName)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSincrpriority (interp, priorityIncr, priority, funcName)
-    Tcl_Interp *interp;
-    int         priorityIncr;
-    int        *priority;
-    char       *funcName;
+TclXOSincrpriority (Tcl_Interp *interp, int priorityIncr, int *priority, char *funcName)
 {
     errno = 0;  /* Old priority might be -1 */
 
@@ -227,9 +225,7 @@ TclXOSincrpriority (interp, priorityIncr, priority, funcName)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSpipe (interp, channels)
-    Tcl_Interp  *interp;
-    Tcl_Channel *channels;
+TclXOSpipe (Tcl_Interp *interp, Tcl_Channel *channels)
 {
     int fileNums [2];
 
@@ -238,11 +234,11 @@ TclXOSpipe (interp, channels)
                               Tcl_PosixError (interp), (char *) NULL);
         return TCL_ERROR;
     }
-    channels [0] = Tcl_MakeFileChannel ((ClientData) fileNums [0],
+    channels [0] = Tcl_MakeFileChannel ((ClientData) (uintptr_t) fileNums [0],
                                         TCL_READABLE);
     Tcl_RegisterChannel (interp, channels [0]);
 
-    channels [1] = Tcl_MakeFileChannel ((ClientData) fileNums [1],
+    channels [1] = Tcl_MakeFileChannel ((ClientData) (uintptr_t) fileNums [1],
                                         TCL_WRITABLE);
     Tcl_RegisterChannel (interp, channels [1]);
 
@@ -264,10 +260,7 @@ TclXOSpipe (interp, channels)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSsetitimer (interp, seconds, funcName)
-    Tcl_Interp *interp;
-    double     *seconds;
-    char       *funcName;
+TclXOSsetitimer (Tcl_Interp *interp, double *seconds, char *funcName)
 {
 /*
  * A million microseconds per seconds.
@@ -315,8 +308,7 @@ TclXOSsetitimer (interp, seconds, funcName)
  *-----------------------------------------------------------------------------
  */
 void
-TclXOSsleep (seconds)
-    unsigned seconds;
+TclXOSsleep (unsigned seconds)
 {
     Tcl_Sleep (seconds*1000);
 }
@@ -345,9 +337,7 @@ TclXOSsync ()
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSfsync (interp, channel)
-    Tcl_Interp *interp;
-    Tcl_Channel channel;
+TclXOSfsync (Tcl_Interp *interp, Tcl_Channel channel)
 {
     if (Tcl_Flush (channel) < 0)
         goto posixError;
@@ -380,10 +370,7 @@ TclXOSfsync (interp, channel)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSsystem (interp, command, exitCode)
-    Tcl_Interp *interp;
-    char       *command;
-    int        *exitCode;
+TclXOSsystem (Tcl_Interp *interp, char *command, int *exitCode)
 {
     int errPipes [2], childErrno;
     pid_t pid;
@@ -415,7 +402,7 @@ TclXOSsystem (interp, command, exitCode)
     if (pid == 0) {
         close (errPipes [0]);
         execl ("/bin/sh", "sh", "-c", command, (char *) NULL);
-        write (errPipes [1], &errno, sizeof (errno));
+        if (write (errPipes [1], &errno, sizeof (errno))) {}
         _exit (127);
     }
 
@@ -482,11 +469,7 @@ TclXOSsystem (interp, command, exitCode)
  *-----------------------------------------------------------------------------
  */
 int
-TclX_OSlink (interp, srcPath, targetPath, funcName)
-    Tcl_Interp *interp;
-    char       *srcPath;
-    char       *targetPath;
-    char       *funcName;
+TclX_OSlink (Tcl_Interp *interp, char *srcPath, char *targetPath, char *funcName)
 {
     if (link (srcPath, targetPath) != 0) {
         TclX_AppendObjResult (interp, "linking \"", srcPath, "\" to \"",
@@ -511,11 +494,7 @@ TclX_OSlink (interp, srcPath, targetPath, funcName)
  *-----------------------------------------------------------------------------
  */
 int
-TclX_OSsymlink (interp, srcPath, targetPath, funcName)
-    Tcl_Interp *interp;
-    char       *srcPath;
-    char       *targetPath;
-    char       *funcName;
+TclX_OSsymlink (Tcl_Interp *interp, char *srcPath, char *targetPath, char *funcName)
 {
 #ifdef S_IFLNK
     if (symlink (srcPath, targetPath) != 0) {
@@ -543,9 +522,7 @@ TclX_OSsymlink (interp, srcPath, targetPath, funcName)
  *-----------------------------------------------------------------------------
  */
 void
-TclXOSElapsedTime (realTime, cpuTime)
-    clock_t *realTime;
-    clock_t *cpuTime;
+TclXOSElapsedTime (clock_t *realTime, clock_t *cpuTime)
 {
 /*
  * If times returns elapsed real time, this is easy.  If it returns a status,
@@ -590,11 +567,7 @@ TclXOSElapsedTime (realTime, cpuTime)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSkill (interp, pid, signal, funcName)
-    Tcl_Interp *interp;
-    pid_t       pid;
-    int         signal;
-    char       *funcName;
+TclXOSkill (Tcl_Interp *interp, pid_t pid, int signal, char *funcName)
 {
     if (kill (pid, signal) < 0) {
         char pidStr [32];
@@ -641,11 +614,7 @@ TclXOSkill (interp, pid, signal, funcName)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSFstat (interp, channel, statBuf, ttyDev)
-    Tcl_Interp  *interp;
-    Tcl_Channel  channel;
-    struct stat *statBuf;
-    int         *ttyDev;
+TclXOSFstat (Tcl_Interp *interp, Tcl_Channel channel, struct stat *statBuf, int *ttyDev)
 {
     int fileNum = ChannelToFnum (channel, 0);
 
@@ -672,10 +641,7 @@ TclXOSFstat (interp, channel, statBuf, ttyDev)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSSeekable (interp, channel, seekablePtr)
-    Tcl_Interp  *interp;
-    Tcl_Channel  channel;
-    int         *seekablePtr;
+TclXOSSeekable (Tcl_Interp *interp, Tcl_Channel channel, int *seekablePtr)
 {
     struct stat statBuf;
     int fileNum = ChannelToFnum (channel, TCL_READABLE);
@@ -722,19 +688,14 @@ TclXOSSeekable (interp, channel, seekablePtr)
  *   TCL_OK if completed directory walk.  TCL_BREAK if callback returned
  * TCL_BREAK and TCL_ERROR if an error occured.
  *-----------------------------------------------------------------------------
- */
+*/
 int
-TclXOSWalkDir (interp, path, hidden, callback, clientData)
-    Tcl_Interp       *interp;
-    char             *path;
-    int               hidden;
-    TclX_WalkDirProc *callback;
-    ClientData        clientData;
+TclXOSWalkDir (Tcl_Interp *interp, char *path, int hidden, TclX_WalkDirProc *callback, ClientData clientData)
 {
     DIR *handle;
     struct dirent *entryPtr;
     int result = TCL_OK;
-    
+
     handle = opendir (path);
     if (handle == NULL)  {
         if (interp != NULL)
@@ -743,7 +704,7 @@ TclXOSWalkDir (interp, path, hidden, callback, clientData)
                                   (char *) NULL);
         return TCL_ERROR;
     }
-   
+
     while (TRUE) {
         entryPtr = readdir (handle);
         if (entryPtr == NULL) {
@@ -786,9 +747,7 @@ TclXOSWalkDir (interp, path, hidden, callback, clientData)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSGetFileSize (channel, fileSize)
-    Tcl_Channel  channel;
-    off_t       *fileSize;
+TclXOSGetFileSize (Tcl_Channel channel, off_t *fileSize)
 {
     struct stat statBuf;
 
@@ -813,11 +772,7 @@ TclXOSGetFileSize (channel, fileSize)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSftruncate (interp, channel, newSize, funcName)
-    Tcl_Interp  *interp;
-    Tcl_Channel  channel;
-    off_t        newSize;
-    char        *funcName;
+TclXOSftruncate (Tcl_Interp *interp, Tcl_Channel channel, off_t newSize, char *funcName)
 {
 #if (!defined(NO_FTRUNCATE)) || defined(HAVE_CHSIZE) 
     int stat;
@@ -850,9 +805,7 @@ TclXOSftruncate (interp, channel, newSize, funcName)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSfork (interp, funcNameObj)
-    Tcl_Interp *interp;
-    Tcl_Obj    *funcNameObj;
+TclXOSfork (Tcl_Interp *interp, Tcl_Obj *funcNameObj)
 {
     pid_t pid;
     
@@ -880,10 +833,7 @@ TclXOSfork (interp, funcNameObj)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSexecl (interp, path, argList)
-    Tcl_Interp *interp;
-    char       *path;
-    char      **argList;
+TclXOSexecl (Tcl_Interp *interp, char *path, char **argList)
 {
     execvp (path, argList);
 
@@ -910,10 +860,7 @@ TclXOSexecl (interp, path, argList)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSInetAtoN (interp, strAddress, inAddress)
-    Tcl_Interp     *interp;
-    char           *strAddress;
-    struct in_addr *inAddress;
+TclXOSInetAtoN (Tcl_Interp *interp, const char *strAddress, struct in_addr *inAddress)
 {
 #ifndef NO_INET_ATON
     if (inet_aton (strAddress, inAddress))
@@ -944,11 +891,7 @@ TclXOSInetAtoN (interp, strAddress, inAddress)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSgetpeername (interp, channel, sockaddr, sockaddrSize)
-    Tcl_Interp *interp;
-    Tcl_Channel channel;
-    void       *sockaddr;
-    int         sockaddrSize;
+TclXOSgetpeername (Tcl_Interp *interp, Tcl_Channel channel, void *sockaddr, socklen_t sockaddrSize)
 {
 
     if (getpeername (ChannelToFnum (channel, 0),
@@ -974,14 +917,11 @@ TclXOSgetpeername (interp, channel, sockaddr, sockaddrSize)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSgetsockname (interp, channel, sockaddr, sockaddrSize)
-    Tcl_Interp *interp;
-    Tcl_Channel channel;
-    void       *sockaddr;
-    int         sockaddrSize;
+TclXOSgetsockname (Tcl_Interp *interp, Tcl_Channel channel, void *sockaddr, int sockaddrSize)
 {
+    socklen_t siz = sockaddrSize;
     if (getsockname (ChannelToFnum (channel, 0),
-		(struct sockaddr *) sockaddr, &sockaddrSize) < 0) {
+		(struct sockaddr *) sockaddr, &siz) < 0) {
 	TclX_AppendObjResult (interp, Tcl_GetChannelName (channel), ": ",
 		Tcl_PosixError (interp), (char *) NULL);
 	return TCL_ERROR;
@@ -1003,13 +943,9 @@ TclXOSgetsockname (interp, channel, sockaddr, sockaddrSize)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSgetsockopt (interp, channel, option, valuePtr)
-    Tcl_Interp  *interp;
-    Tcl_Channel  channel;
-    int          option;
-    int         *valuePtr;
+TclXOSgetsockopt (Tcl_Interp *interp, Tcl_Channel channel, int option, socklen_t *valuePtr)
 {
-    int valueLen = sizeof (*valuePtr);
+    socklen_t valueLen = sizeof (*valuePtr);
 
     if (getsockopt (ChannelToFnum (channel, 0), SOL_SOCKET, option, 
 		(void*) valuePtr, &valueLen) != 0) {
@@ -1034,11 +970,7 @@ TclXOSgetsockopt (interp, channel, option, valuePtr)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSsetsockopt (interp, channel, option, value)
-    Tcl_Interp  *interp;
-    Tcl_Channel  channel;
-    int          option;
-    int          value;
+TclXOSsetsockopt (Tcl_Interp *interp, Tcl_Channel channel, int option, int value)
 {
     int valueLen = sizeof (value);
 
@@ -1064,10 +996,7 @@ TclXOSsetsockopt (interp, channel, option, value)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSchmod (interp, fileName, mode)
-    Tcl_Interp *interp;
-    char       *fileName;
-    int         mode;
+TclXOSchmod (Tcl_Interp *interp, char *fileName, int mode)
 {
     if (chmod (fileName, mode) < 0) {
         TclX_AppendObjResult (interp, fileName, ": ",
@@ -1091,11 +1020,7 @@ TclXOSchmod (interp, fileName, mode)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSfchmod (interp, channel, mode, funcName)
-    Tcl_Interp *interp;
-    Tcl_Channel channel;
-    int         mode;
-    char       *funcName;
+TclXOSfchmod (Tcl_Interp *interp, Tcl_Channel channel, int mode, char *funcName)
 {
 #ifndef NO_FCHMOD
     if (fchmod (ChannelToFnum (channel, 0), mode) < 0) {
@@ -1131,13 +1056,12 @@ TclXOSfchmod (interp, channel, mode, funcName)
  *-----------------------------------------------------------------------------
  */
 static int
-ConvertOwnerGroup (interp, options, ownerStr, groupStr, ownerId, groupId)
-    Tcl_Interp  *interp;
-    unsigned     options;
-    char        *ownerStr;
-    char        *groupStr;
-    uid_t       *ownerId;
-    gid_t       *groupId;
+ConvertOwnerGroup (Tcl_Interp  *interp,
+                   unsigned     options,
+                   char        *ownerStr,
+                   char        *groupStr,
+                   uid_t       *ownerId,
+                   gid_t       *groupId)
 {
     struct passwd *passwdPtr = NULL;
     struct group *groupPtr = NULL;
@@ -1229,13 +1153,12 @@ ConvertOwnerGroup (interp, options, ownerStr, groupStr, ownerId, groupId)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSChangeOwnGrpObj (interp, options, ownerStr, groupStr, fileListObj, funcName)
-    Tcl_Interp  *interp;
-    unsigned     options;
-    char        *ownerStr;
-    char        *groupStr;
-    Tcl_Obj     *fileListObj;
-    char        *funcName;
+TclXOSChangeOwnGrpObj  (Tcl_Interp *interp,
+                        unsigned options,
+                        char *ownerStr,
+                        char *groupStr,
+                        Tcl_Obj *fileListObj,
+                        char *funcName)
 {
     int          idx;
     struct stat  fileStat;
@@ -1312,14 +1235,12 @@ TclXOSChangeOwnGrpObj (interp, options, ownerStr, groupStr, fileListObj, funcNam
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSFChangeOwnGrpObj (interp, options, ownerStr, groupStr, channelIdsObj,
-                        funcName)
-    Tcl_Interp *interp;
-    unsigned    options;
-    char       *ownerStr;
-    char       *groupStr;
-    Tcl_Obj    *channelIdsObj;
-    char       *funcName;
+TclXOSFChangeOwnGrpObj (Tcl_Interp *interp,
+                        unsigned options,
+                        char *ownerStr,
+                        char *groupStr,
+                        Tcl_Obj *channelIdsObj,
+                        char *funcName)
 {
 #ifndef NO_FCHOWN
     int          idx, fnum;
@@ -1394,13 +1315,7 @@ TclXOSFChangeOwnGrpObj (interp, options, ownerStr, groupStr, channelIdsObj,
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSFChangeOwnGrp (interp, options, ownerStr, groupStr, channelIds, funcName)
-    Tcl_Interp *interp;
-    unsigned    options;
-    char       *ownerStr;
-    char       *groupStr;
-    char      **channelIds;
-    char       *funcName;
+TclXOSFChangeOwnGrp (Tcl_Interp *interp, unsigned options, char *ownerStr, char *groupStr, char **channelIds, char *funcName)
 {
 #ifndef NO_FCHOWN
     int idx, fnum;
@@ -1461,11 +1376,7 @@ TclXOSFChangeOwnGrp (interp, options, ownerStr, groupStr, channelIds, funcName)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSGetSelectFnum (interp, channel, direction, fnumPtr)
-    Tcl_Interp *interp;
-    Tcl_Channel channel;
-    int         direction;
-    unsigned int *fnumPtr;
+TclXOSGetSelectFnum (Tcl_Interp *interp, Tcl_Channel channel, int direction, int *fnumPtr)
 {
     ClientData handle;
 
@@ -1476,7 +1387,7 @@ TclXOSGetSelectFnum (interp, channel, direction, fnumPtr)
                               (char *) NULL);
         return TCL_ERROR;
     }
-    *fnumPtr = (unsigned int) handle;
+    *fnumPtr = (intptr_t) handle;
     return TCL_OK;
 }
 
@@ -1510,9 +1421,7 @@ TclXOSHaveFlock ()
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSFlock (interp, lockInfoPtr)
-    Tcl_Interp     *interp;
-    TclX_FlockInfo *lockInfoPtr;
+TclXOSFlock (Tcl_Interp *interp, TclX_FlockInfo *lockInfoPtr)
 {
 #ifdef F_SETLKW
     int fnum, stat;
@@ -1568,9 +1477,7 @@ TclXOSFlock (interp, lockInfoPtr)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSFunlock (interp, lockInfoPtr)
-    Tcl_Interp     *interp;
-    TclX_FlockInfo *lockInfoPtr;
+TclXOSFunlock (Tcl_Interp *interp, TclX_FlockInfo *lockInfoPtr)
 {
 #ifdef F_SETLKW
     int fnum, stat;
@@ -1612,10 +1519,7 @@ TclXOSFunlock (interp, lockInfoPtr)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSGetAppend (interp, channel, valuePtr)
-    Tcl_Interp *interp;
-    Tcl_Channel channel;
-    int        *valuePtr;
+TclXOSGetAppend (Tcl_Interp *interp, Tcl_Channel channel, int *valuePtr)
 {
     int fnum, mode;
 
@@ -1654,10 +1558,7 @@ TclXOSGetAppend (interp, channel, valuePtr)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSSetAppend (interp, channel, value)
-    Tcl_Interp *interp;
-    Tcl_Channel channel;
-    int         value;
+TclXOSSetAppend (Tcl_Interp *interp, Tcl_Channel channel, int value)
 {
     int fnum, mode;
 
@@ -1700,10 +1601,7 @@ TclXOSSetAppend (interp, channel, value)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSGetCloseOnExec (interp, channel, valuePtr)
-    Tcl_Interp *interp;
-    Tcl_Channel channel;
-    int        *valuePtr;
+TclXOSGetCloseOnExec (Tcl_Interp *interp, Tcl_Channel channel, int *valuePtr)
 {
     int     readFnum;
     int     writeFnum;
@@ -1764,10 +1662,7 @@ TclXOSGetCloseOnExec (interp, channel, valuePtr)
  *-----------------------------------------------------------------------------
  */
 int
-TclXOSSetCloseOnExec (interp, channel, value)
-    Tcl_Interp *interp;
-    Tcl_Channel channel;
-    int         value;
+TclXOSSetCloseOnExec (Tcl_Interp *interp, Tcl_Channel channel, int value)
 {
     int readFnum, writeFnum;
 
@@ -1790,4 +1685,4 @@ TclXOSSetCloseOnExec (interp, channel, value)
     return TCL_ERROR;
 }
 
-
+/* vim: set ts=4 sw=4 sts=4 et : */
